// Certificate.h: interface for the CCertificate class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_CERTIFICATE_H__A03B0F6D_6719_11D3_80B3_00A0C9E2EA8A__INCLUDED_)
#define AFX_CERTIFICATE_H__A03B0F6D_6719_11D3_80B3_00A0C9E2EA8A__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "Context.h"
#include "DLLDefs.h"
#include <vtk_defs.h>

class VString;
class CCertificateInfo;
class CExtensions;
class CValRespDetails;
class CValRespSingleCertDetails;

class __exportVTKC CCertificate
{
	friend void CContext::GetOcspSignInfo(Vtk_OCSPSignCallback& callback, void*& userHdl, 
							   CCertificate& signerCert) const;

private:

	// Temporary (until necessary functions from Toolkit are provided)
	// make copy constructor and assign operator not available
	CCertificate(const CCertificate& obj);
	CCertificate& operator=(const CCertificate& obj);

public:
	CCertificate();

	// Constructor for VTK_DF_BASE64 Certificate only
	CCertificate(const CContext& context, const VString& source);
	// Constructor for certificates in any data format
	CCertificate(const CContext& context, const unsigned char *pSource, int size,
		         enum Vtk_DataFormat format);
	CCertificate(const CContext& context, const VString& fileName, 
		         enum Vtk_DataFormat format);

	virtual ~CCertificate();

	// Get certificate structure
	const Vtk_Cert* GetVtkCert() const {return this->m_pCert;};

	// Get certificate information
	void GetCertInfo(const CContext& context, CCertificateInfo& certInfo) const;

	// Get issuer certificate
	void GetIssuerCert(const CContext& context, CCertificate &issuerCert) const;

	// Get extensions of the certificate
	void GetExtensions(const CContext& context, CExtensions& extsOut) const;


	// Performs a CRL certificate validation. This function does not require 
	// CValidation object. Configuration data to obtain the CRL is obtained 
	// from the context.
	// The respDetails and certDetails parameters are optional.
	void CRLValidate(const CContext& context, Vtk_uint32 *pStatus,
					 CValRespDetails *pRespDetails = NULL, 
					 CValRespSingleCertDetails *pCertDetail = NULL) const;


protected:

	// Structure that contains actual X.509 certificate
	Vtk_Cert *m_pCert;

};

#endif // !defined(AFX_CERTIFICATE_H__A03B0F6D_6719_11D3_80B3_00A0C9E2EA8A__INCLUDED_)
