// CertificateStore.cpp: implementation of the CCertificateStore class.
//
//////////////////////////////////////////////////////////////////////

#include "CertificateStore.h"
#include "Certificate.h"
#include "Context.h"
#include "VString.h"
#include <vtk_cert.h>
#include <vtk_error.h>
#include <cassert>

/*
#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif
*/

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CCertificateStore::CCertificateStore():m_pCertStore(NULL)
{
}


CCertificateStore::CCertificateStore(const CContext& context)
{
	assert(context.GetVtkCtxt());

	// Allocate space for this certificate store
	m_pCertStore = Vtk_CertStoreNew(context.GetVtkCtxt());
	if (m_pCertStore == NULL)
		throw VString("Certificate store initialization failed.");
}


CCertificateStore::CCertificateStore(const CContext& context, const VString& fileName, 
						             enum Vtk_DataFormat format)
{
	assert(context.GetVtkCtxt());

	// Allocate space for this certificate store
	m_pCertStore = Vtk_CertStoreNew(context.GetVtkCtxt());
	if (m_pCertStore == NULL)
		throw VString("Certificate initialization failed.");

	// Init certificate store from File
	Vtk_uint32 nRet = Vtk_CertStoreLoadFromFile(context.GetVtkCtxt(), m_pCertStore, 
		                                        fileName.c_str(), format);
	if (nRet != VTK_OK)
	{
		// Clean up memory
		Vtk_CertStoreDelete(m_pCertStore);

		VString error(Vtk_ErrorToString(nRet));
		throw error;
	}
}


CCertificateStore::CCertificateStore(const CCertificateStore& obj)
{
	*this = obj;
}

CCertificateStore& CCertificateStore::operator=(const CCertificateStore& obj)
{
	if (this != &obj)
	{
		// BUGBUG
		// Assignment function is temporary not available !
		// Support from Toolkit Validator is needed. Possible solutions:
		//  - copy Vtk_CertStore structure
		//  - increase reference counter in for Vtk_CertStore structure of obj

		// this->m_pCertStore = obj.m_pCertStore;
		throw VString("Assignment of CCertificateStore is not supported.");
	}
	return *this;
}


CCertificateStore::~CCertificateStore()
{
	if (m_pCertStore)
		Vtk_CertStoreDelete(m_pCertStore);
}



void CCertificateStore::AddCertificate(const CContext& context, const CCertificate& cert)
{
	assert(context.GetVtkCtxt());
	assert(cert.GetVtkCert());
	assert(m_pCertStore);

	// Add individual certificate to the store
	Vtk_uint32 nRet = Vtk_CertStoreAddCert(context.GetVtkCtxt(), m_pCertStore, cert.GetVtkCert());
	if (nRet != VTK_OK)
	{
		VString error(Vtk_ErrorToString(nRet));
		throw error;
	}
}


void CCertificateStore::AddCertificate(const CContext& context, const unsigned char *pSource, 
									   int size, enum Vtk_DataFormat format)
{
	assert(context.GetVtkCtxt());
	assert(pSource);
	assert(m_pCertStore);

	// Copy input parameters into a Vtk_Buffer
	Vtk_Buffer buffer;
	buffer.dPtr = const_cast<unsigned char*>(pSource);
	buffer.len  = size;
	buffer.type = format;

	// Add individual certificate to the store
	Vtk_uint32 nRet = Vtk_CertStoreAddCertRaw(context.GetVtkCtxt(), m_pCertStore, &buffer);
	if (nRet != VTK_OK)
	{
		VString error(Vtk_ErrorToString(nRet));
		throw error;
	}
}
