// Context.h: interface for the CContext class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_CONTEXT_H__A03B0F6E_6719_11D3_80B3_00A0C9E2EA8A__INCLUDED_)
#define AFX_CONTEXT_H__A03B0F6E_6719_11D3_80B3_00A0C9E2EA8A__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "DLLDefs.h"
#include <vtk_ctxt.h>


class VString;
class CCertificate;
class CCertificateStore;
class CProtocolDetails;

class __exportVTKC CContext  
{
private:

	// Temporary (until necessary functions from Toolkit are provided)
	// make copy constructor and assign operator not available
	CContext(const CContext& obj);
	CContext& operator=(const CContext& obj);

public:
	CContext();
	virtual ~CContext();

	// Get validation context structure
	const Vtk_Ctxt* GetVtkCtxt() const {return this->m_pCtxt;};

	// Set default VA mechanism 
	void SetDefaultVa(Vtk_ValidationMech valMech, const VString& vaUrl);

	// Add a certificate to the list of trusted certificates
	void AddCertificate(const CCertificate& cert, int type);
	void AddCertificates(const CCertificateStore& certStore, int type);

	// Sets the validation information specific to an individual CA.
	void SetVaInfo(const CCertificate& cert, const VString& vaUrl, 
		           enum Vtk_ValidationMech mech, const CProtocolDetails* pDetails =NULL,  
				   const CCertificateStore* pCertStore =NULL);



	// Accessors and Mutators for context options
	//////////////////////////////////////////////////////////////////
	void SetHttpProxy(const VString& host, int port);
	void GetHttpProxy(VString& host, int& port) const;

	void SetServiceLocExt(bool bVal);
	bool GetServiceLocExt() const;

	void SetClientInfExt(bool bVal);
	bool GetClientInfExt() const;

	void SetOscpNonceExt(bool bVal);
	bool GetOscpNonceExt() const;

	void SetMaxTimeSkew(int val);
	int  GetMaxTimeSkew() const;

	void SetUseAiaData(bool bVal);
	bool GetUseAiaData() const;

	void SetLoadLDAPLib(bool bVal);
	bool GetLoadLDAPLib() const;

	void SetCrlCacheDir(const VString& dir);
	void GetCrlCacheDir(VString& dir) const;

	void SetMaxCrlCacheTime(int val);
	int  GetMaxCrlCacheTime() const;

	void SetCrlNoNextUpdateCacheTime(int val);
	int  GetCrlNoNextUpdateCacheTime() const;

	void SetLdapSearchTimeOut(int val);
	int  GetLdapSearchTimeOut() const;

	void SetDelegatedCertCb(Vtk_DelegatedCertCallback callback, void* userHdl);
	void GetDelegatedCertCb(Vtk_DelegatedCertCallback& callback, void*& userHdl) const;

	void SetOcspSignInfo(Vtk_OCSPSignCallback callback, void* userHdl, 
						 const CCertificate& signerCert);
	void GetOcspSignInfo(Vtk_OCSPSignCallback& callback, void*& userHdl, 
						 CCertificate& signerCert) const;

protected:

	// Help function for option accessors and mutators
	void SetIntOption(enum Vtk_CtxtOptionType type, int val);
	int  GetIntOption(enum Vtk_CtxtOptionType type) const;


	// Validation context structure
	Vtk_Ctxt *m_pCtxt;

	// Reference counter
	static int m_refCount;
};

#endif // !defined(AFX_CONTEXT_H__A03B0F6E_6719_11D3_80B3_00A0C9E2EA8A__INCLUDED_)
