// Extension.h: interface for the CExtension class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_EXTENSION_H__CB0B7224_9874_11D3_80E7_00A0C9E2EA8A__INCLUDED_)
#define AFX_EXTENSION_H__CB0B7224_9874_11D3_80E7_00A0C9E2EA8A__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include <vector>
#include <iostream>
#include "VString.h"
#include "Certificate.h"
#include "DLLDefs.h"


class CContext;

class __exportVTKC CExtension  
{
	friend class CExtensions;
private:

	// Temporary (until necessary functions from Toolkit are provided)
	// make copy constructor and assign operator not available
	CExtension(const CExtension& obj);
	CExtension& operator=(const CExtension& obj);

public:
	CExtension();
	CExtension(const CContext& context, const VString& oid, const unsigned char *pValue,
		int valueLen, int critical);
	virtual ~CExtension();

	// Get Vtk_Extension structure
	const Vtk_Extension* GetVtkExt() const {return this->m_pExt;};

	// Checks if object is null
	bool IsNull() const { return m_pExt == NULL ? true : false; }

	// Accessors (should be used only on non-Null object)
	VString Oid() const;
	int Critical() const;
	void Value(vector<unsigned char>& valueOut) const;

	// Flag that indicates if also binary value of the extension should be printed
	static bool m_printValue;

protected:

	// Structure that contains actual X509 extension
	Vtk_Extension *m_pExt;

};

__exportVTKC ostream& operator << (ostream& os, const CExtension& obj);




class __exportVTKC CExtensions
{
	friend void CCertificate::GetExtensions(const CContext& context, CExtensions& extsOut) const;
	
private:

	// Temporary (until necessary functions from Toolkit are provided)
	// make copy constructor and assign operator not available
	CExtensions(const CExtensions& obj);
	CExtensions& operator=(const CExtensions& obj);

public:
	CExtensions();
	virtual ~CExtensions();


	// Checks if object is null
	bool IsNull() const { return m_pExts == NULL ? true : false; }

	// Number of extensions in list of extensions
	int Size(const CContext& context) const;

	// Get extension specified by index
	void GetAt(const CContext& context, int nIndex, CExtension& extOut) const;

	// Get extension specified by Oid
	void GetByOid(const CContext& context, const VString& oid, CExtension& extOut) const;

	// Print to standard output
	void Print(ostream& os, const CContext& context) const;


protected:

	// Structure that contains list of X509 extensions
	Vtk_Extensions *m_pExts;
};




#endif // !defined(AFX_EXTENSION_H__CB0B7224_9874_11D3_80E7_00A0C9E2EA8A__INCLUDED_)
