// Log.h: interface for the CLog class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_LOG_H__38A0A504_D9BD_11D3_80FB_00A0C9E2EA8A__INCLUDED_)
#define AFX_LOG_H__38A0A504_D9BD_11D3_80FB_00A0C9E2EA8A__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "DLLDefs.h"
#include "VString.h"
#include <vtk_defs.h>


class CContext;

class __exportVTKC CLog  
{

public:
	CLog();
	CLog(const CLog& obj);
	CLog::CLog(enum Vtk_CtxtLogType logLevel, 
	           bool overwriteLogFile = false,
	           bool flushEachMessage = false,
	           const VString& logFileName = VString(), 
	           Vtk_OpenLogCallback openLogCB = NULL,
	           Vtk_CloseLogCallback closeLogCB = NULL,
	           Vtk_WriteLogCallback writeLogCB = NULL);
	virtual ~CLog();

	CLog& operator=(const CLog& obj);

	// Accessors
	enum Vtk_CtxtLogType  LogLevel() const {return this->m_logOptions.logLevel;};
	bool OverwriteLogFile() const 
	{ 
		return (this->m_logOptions.logMode & VTK_LOG_MODE_OVERWRITE) ? true : false; 
	};
	bool FlushEachMessage() const 
	{ 
		return (this->m_logOptions.logMode & VTK_LOG_MODE_FLUSH) ? true : false; 
	};

	const VString LogFileName() const 
	{
		if (this->m_logOptions.logFileName.dPtr)
			return VString((const char *)this->m_logOptions.logFileName.dPtr);
		else
			return VString();
	};
	Vtk_OpenLogCallback OpenLogCallback() const {return this->m_logOptions.openLogCB;};
	Vtk_CloseLogCallback CloseLogCallback() const {return this->m_logOptions.closeLogCB;};
	Vtk_WriteLogCallback WriteLogCallback() const {return this->m_logOptions.writeLogCB;};

	
	// Main Log Functions - Open, Write, Close
	void OpenLog(CContext& context);
	void CloseLog(CContext& context);
	void WriteLog(const CContext& context, enum Vtk_CtxtLogType type, const VString& msg);


protected:
	// Toolkit logging options.
	Vtk_LogOptions m_logOptions;

};

#endif // !defined(AFX_LOG_H__38A0A504_D9BD_11D3_80FB_00A0C9E2EA8A__INCLUDED_)

