// ValHdl.cpp: implementation of the CValHdl class.
//
//////////////////////////////////////////////////////////////////////

#include "ValHdl.h"
#include "Context.h"
#include "ValRespDetails.h"
#include "ValRespSingleCertDetails.h"
#include "Extension.h"
#include <cassert>
#include <vtk_valid.h>
#include <vtk_error.h>

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CValHdl::CValHdl():m_pHdl(NULL)
{
}

CValHdl::~CValHdl()
{
	if (m_pHdl)
		Vtk_ValHdlDelete(m_pHdl);
}


CValHdl::CValHdl(const CValHdl& obj)
{
	*this = obj;
}

CValHdl& CValHdl::operator=(const CValHdl& obj)
{
	if (this != &obj)
	{
		// BUGBUG
		// Temporary the assignment is not allowed !
		// Support from Toolkit Validator is needed.
		throw VString("Assignment of CValHdl is not supported.");
	}
	return *this;
}



void CValHdl::GetRevStatus(const CContext& context, Vtk_uint32 *pStatus, 
							  CValRespDetails *pRespDetails /*=NULL*/,
							  CValRespSingleCertDetails *pCertDetails /*=NULL*/) const
{
	assert(context.GetVtkCtxt());
	assert(m_pHdl);

	// Get Vtk_ValRespDetails for Vtk_CRLValidateCert (if not Null)
	Vtk_ValRespDetails **respDetails = NULL;
	if (pRespDetails)
		respDetails = &(pRespDetails->m_pRespDetails);

	// Get Vtk_ValRespDetails for Vtk_CRLValidateCert (if not Null)
	Vtk_ValRespSingleCertDetails **certDetails = NULL;
	if (pCertDetails)
		certDetails = &(pCertDetails->m_pCertDetails);

	// Retrive validation status information for a single certificate.
	Vtk_uint32 nRet = Vtk_ValHdlGetRevStatus(context.GetVtkCtxt(), m_pHdl,
		                                     pStatus, respDetails, certDetails);
	if (nRet != VTK_OK)
	{
		VString error(Vtk_ErrorToString(nRet));
		throw error;
	}
}


void CValHdl::AddReqExtForSingleCert(const CContext& context, const CExtension& ext)
{
	assert(context.GetVtkCtxt());
	assert(ext.GetVtkExt());
	assert(m_pHdl);

	// Adds extension to OCSP validation request for particular certificate
	Vtk_uint32 nRet = Vtk_ValidationAddReqExtForSingleCertHdl(context.GetVtkCtxt(),
	                                      m_pHdl, ext.GetVtkExt());
	if (nRet != VTK_OK)
	{
		VString error(Vtk_ErrorToString(nRet));
		throw error;
	}
}
