// ValHdl.h: interface for the CValHdl class.
//
//////////////////////////////////////////////////////////////////////
//
// Vtk_ValHdl is used to identify a specific certificate in the
// validation query. It can be used to obtain validation status specific
// to that certificate, set/get single certificate extensions.


#if !defined(AFX_VALHDL_H__98CB56F3_9DFA_11D3_80E9_00A0C9E2EA8A__INCLUDED_)
#define AFX_VALHDL_H__98CB56F3_9DFA_11D3_80E9_00A0C9E2EA8A__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "Validator.h"

class CContext;
class CValRespDetails;
class CValRespSingleCertDetails;
class CExtension;

class __exportVTKC CValHdl  
{
	// Following friends are only function that can set Vtk_ValHdl data
	friend void CValidator::AddCertificate(const CContext& context, 
		const CCertificate& cert, const CCertificate& issuerCert, CValHdl *pHdl/*=NULL*/);

	friend void CValidator::AddCertificate(const CContext& context, 
		const unsigned char *pCertSource, int certSize, enum Vtk_DataFormat certFormat, 
		const unsigned char *pIssuerCertSource, int issuerCertSize, 
		enum Vtk_DataFormat issuerCertFormat, CValHdl *pHdl/*=NULL*/);

	friend void CValidator::GetValHdl(const CContext& context, const CCertificate& cert,
	    const CCertificate *pIssuerCert, CValHdl *pHdl);


private:

	// Temporary (until necessary functions from Toolkit are provided)
	// make copy constructor and assign operator not available
	CValHdl(const CValHdl& obj);
	CValHdl& operator=(const CValHdl& obj);


public:
	CValHdl();
	virtual ~CValHdl();

	// Check if structure Vtk_ValHdl was initialized
	bool IsNull() const { return m_pHdl == NULL ? true : false; }

	// Get Vtk_ValHdl structure - Not needed right now, might be useful later
//	const Vtk_ValHdl* GetVtkValHdl() const {return this->m_pHdl;};


	// Retrieves validation status information for a single certificate.
	void GetRevStatus(const CContext& context, Vtk_uint32 *pStatus, 
					  CValRespDetails *pRespDetails = NULL,
					  CValRespSingleCertDetails *pCertDetails =NULL) const;

	// Sets extension in Va request for particular certificate
	// Certificate is specified by (this) CValHdl
	void AddReqExtForSingleCert(const CContext& context, const CExtension& ext);


protected:

	Vtk_ValHdl *m_pHdl;

};

#endif // !defined(AFX_VALHDL_H__98CB56F3_9DFA_11D3_80E9_00A0C9E2EA8A__INCLUDED_)
