// ValRespSingleCertDetails.cpp: implementation of the CValRespSingleCertDetails class.
//
//////////////////////////////////////////////////////////////////////

#include "ValRespSingleCertDetails.h"
#include "Extension.h"
#include <vtk_cert.h>
#include <vtk_valid.h>
#include <vtk_error.h>
#include <cassert>


//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CValRespSingleCertDetails::CValRespSingleCertDetails():m_pCertDetails(NULL)
{
}

CValRespSingleCertDetails::~CValRespSingleCertDetails()
{
	if (m_pCertDetails)
		Vtk_ValRespSingleCertDetailsDelete(m_pCertDetails);
}


CValRespSingleCertDetails::CValRespSingleCertDetails(const CValRespSingleCertDetails& obj)
{
	*this = obj;
}

CValRespSingleCertDetails& CValRespSingleCertDetails::operator=(const CValRespSingleCertDetails& obj)
{
	if (this != &obj)
	{
		// BUGBUG
		// Temporary the assignment is not allowed !
		// Support from Toolkit Validator is needed.
		throw VString("Assignment of CValRespSingleCertDetails is not supported.");
	}
	return *this;
}



/////////////////////////////////////////////////////////////////////////
// Accesssors to Vtk_ValRespSingleCertDetails data structure


enum Vtk_ValidationMech CValRespSingleCertDetails::ValidationMech() const
{
	assert(m_pCertDetails);
	return m_pCertDetails->type;
}

Vtk_uint32 CValRespSingleCertDetails::CertStatus() const
{
	assert(m_pCertDetails);
	return m_pCertDetails->certStatus;
}


VString CValRespSingleCertDetails::CertStringStatus() const
{
	assert(m_pCertDetails);
	VString strOut;

	// Put status into the string
	char ** statusStrings = Vtk_StatusToStrings(m_pCertDetails->certStatus);
	if (statusStrings)
	{
		char **temp = statusStrings;

		// Walk through the array of strings returned, printing each string,
		// until the end of array is reached - NULL entry.
		while (*temp)
		{
			strOut += *temp;
			strOut += "\t";
			temp++;
		}

		// Release status array.
		Vtk_StatusStringsDelete(statusStrings);
	}

	return strOut;
}


time_t CValRespSingleCertDetails::ThisUpdate() const
{
	assert(m_pCertDetails);
	return m_pCertDetails->thisUpdate;
}

time_t CValRespSingleCertDetails::NextUpdate() const
{
	assert(m_pCertDetails);
	return m_pCertDetails->nextUpdate;
}

time_t CValRespSingleCertDetails::RevocationTime() const
{
	assert(m_pCertDetails);
	return m_pCertDetails->revocationTime;
}

enum Vtk_RevocationReason CValRespSingleCertDetails::RevocationReason() const
{
	assert(m_pCertDetails);
	return m_pCertDetails->revocationReason;
}



void CValRespSingleCertDetails::Print(ostream& os, const CContext& context) const
{
	assert(context.GetVtkCtxt());

	cout << "Validation Mechanism: ";
	if (ValidationMech() == VTK_VM_CRT)
		cout << "CRT" << endl;
	else if (ValidationMech() == VTK_VM_OCSP)
		cout << "OCSP" << endl;
	else if (ValidationMech() == VTK_VM_CRL)
		cout << "CRL" << endl;
	else
		cout << "Unset" << endl;

	VString strStatus = CertStringStatus();
	cout << "Certificate Status:   " << strStatus << endl;
	time_t thisUpdate = ThisUpdate();
	if (thisUpdate > 0)
		cout << "This Update:          " << ctime(&thisUpdate);
	else
		cout << "This Update:          " << "Unset" << endl;

	time_t nextUpdate = NextUpdate();
	if (nextUpdate > 0)
		cout << "Next Update:          " << ctime(&nextUpdate);
	else
		cout << "Next Update:          " << "Unset" << endl;

	time_t revocationTime = RevocationTime();
	if (revocationTime > 0)
		cout << "Revocation Time:      " << ctime(&revocationTime);
	else
		cout << "Revocation Time:      " << "Unset" << endl;


	enum Vtk_RevocationReason revReason = RevocationReason();
	cout << "Revocation Reason:    ";
	if (revReason == VTK_REV_STATUS_UNKNOWN)
		cout << "Unknown" << endl;
	else if (revReason == VTK_REV_UNSPECIFIED)
		cout << "Unspecified" << endl;
	else if (revReason == VTK_REV_KEY_COMPROMISE)
		cout << "Key Compromised" << endl;
	else if (revReason == VTK_REV_CA_COMPROMISE)
		cout << "CA Compromised" << endl;
	else if (revReason == VTK_REV_AFFILIATION_CHANGED)
		cout << "Affiliation Changed" << endl;
	else if (revReason == VTK_REV_SUPERSEDED)
		cout << "Superseded" << endl;
	else if (revReason == VTK_REV_CESSATION_OF_OPERATION)
		cout << "Cessation Of Operation" << endl;
	else if (revReason == VTK_REV_CERTIFICATE_HOLD)
		cout << "Certificate Hold" << endl;
	else if (revReason == VTK_REV_REMOVE_FROM_CRL)
		cout << "Removed From CRL" << endl;
	else
		cout << "Unset" << endl;

	// Exceptions
	int numExts = 0;
	if (m_pCertDetails->extensions)
		numExts = Vtk_ExtensionsGetCount(context.GetVtkCtxt(), m_pCertDetails->extensions);

	cout << "Number of Exceptions: " << numExts << endl;
}


